"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = require("axios");
const vscode = require("vscode");
const issue_1 = require("./issue");
const configurationProvider_1 = require("./configurationProvider");
class OpenIssuesProvider {
    constructor() {
        this._onDidChangeTreeData = new vscode.EventEmitter();
        this.onDidChangeTreeData = this._onDidChangeTreeData.event;
        this.issueList = [];
        // Auto update the issuelist after 10 minutes
        setInterval(() => {
            this.refresh();
        }, 10 * 60 * 1000);
    }
    refresh() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.getChildrenAsync();
            this._onDidChangeTreeData.fire();
        });
    }
    getTreeItem(element) {
        return element;
    }
    /**
     * Returns a list of all open issues;
     */
    getChildrenAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            this.issueList = [];
            const repoMng = new configurationProvider_1.RepositoryInformationManager();
            const repoUri = repoMng.repoApiUrl(vscode.workspace.rootPath);
            const token = repoMng.token(vscode.workspace.rootPath);
            let stop = false;
            for (let i = 0; i !== 10; i++) {
                yield axios_1.default.get(repoUri + "?page=" + i, { headers: { Authorization: "token " + token } }).then(res => {
                    for (const issue of res.data) {
                        const id = issue["number"];
                        let isAlreadyInList = false;
                        this.issueList.forEach((issueOfList) => {
                            if (id === issueOfList.issueId) {
                                isAlreadyInList = true;
                            }
                        });
                        if (isAlreadyInList) {
                            continue;
                        }
                        const title = issue["title"];
                        const body = issue["body"];
                        const state = issue["state"];
                        const assignee = issue["assignee"] === null ? "None" : issue["assignee"]["username"];
                        const tmpIssue = new issue_1.Issue("#" + id + " - " + title, id, body, state, assignee, "Frontend", vscode.TreeItemCollapsibleState.None);
                        const issueForList = new issue_1.Issue(tmpIssue.label, tmpIssue.issueId, tmpIssue.body, tmpIssue.issueState, tmpIssue.assignee, tmpIssue.firstlabel, tmpIssue.collapsibleState, {
                            command: 'giteaIssues.openIssue',
                            title: '',
                            arguments: [tmpIssue],
                        });
                        this.issueList.push(issueForList);
                    }
                }).catch(() => {
                    stop = true;
                    vscode.window.showErrorMessage("Can't fetch issues; HTTP Error!");
                    return;
                });
                if (stop) {
                    return;
                }
            }
        });
    }
    getChildren(element) {
        return this.issueList;
    }
}
exports.OpenIssuesProvider = OpenIssuesProvider;
class ClosedIssuesProvider {
    constructor() {
        this._onDidChangeTreeData = new vscode.EventEmitter();
        this.onDidChangeTreeData = this._onDidChangeTreeData.event;
        this.issueList = [];
        setInterval(() => {
            this.refresh();
        }, 10 * 60 * 1000);
    }
    refresh() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.getChildrenAsync();
            this._onDidChangeTreeData.fire();
        });
    }
    getTreeItem(element) {
        return element;
    }
    getChildrenAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            this.issueList = [];
            const repoMng = new configurationProvider_1.RepositoryInformationManager();
            const repoUri = repoMng.repoApiUrl(vscode.workspace.rootPath);
            const token = repoMng.token(vscode.workspace.rootPath);
            let stop = false;
            for (let i = 0; i !== 10; i++) {
                yield axios_1.default.get(repoUri + "?state=closed&page=" + i, { headers: { Authorization: "token " + token } }).then(res => {
                    for (const issue of res.data) {
                        const id = issue["number"];
                        let isAlreadyInList = false;
                        this.issueList.forEach((issueOfList) => {
                            if (id === issueOfList.issueId) {
                                isAlreadyInList = true;
                            }
                        });
                        if (isAlreadyInList) {
                            continue;
                        }
                        const title = issue["title"];
                        const body = issue["body"];
                        const state = issue["state"];
                        const assignee = issue["assignee"] === null ? "None" : issue["assignee"]["username"];
                        const tmpIssue = new issue_1.Issue("#" + id + " - " + title, id, body, state, assignee, "Frontend", vscode.TreeItemCollapsibleState.None);
                        const issueForList = new issue_1.Issue(tmpIssue.label, tmpIssue.issueId, tmpIssue.body, tmpIssue.issueState, tmpIssue.assignee, tmpIssue.firstlabel, tmpIssue.collapsibleState, {
                            command: 'giteaIssues.openIssue',
                            title: '',
                            arguments: [tmpIssue],
                        });
                        this.issueList.push(issueForList);
                    }
                }).catch(() => {
                    stop = true;
                    vscode.window.showErrorMessage("Can't fetch issues; HTTP Error!");
                    return;
                });
                if (stop) {
                    return;
                }
            }
        });
    }
    getChildren(element) {
        return this.issueList;
    }
}
exports.ClosedIssuesProvider = ClosedIssuesProvider;
//# sourceMappingURL=issueProvider.js.map